@@ -6,7 +6,7 @@ use Rose::HTML::Form::Field::DateTime;
 use Rose::HTML::Form::Field::Compound;
 our @ISA = qw(Rose::HTML::Form::Field::Compound Rose::HTML::Form::Field::DateTime);
 
-our $VERSION = '0.011';
+our $VERSION = '0.02';
 
 # Multiple inheritence never quite works out the way I want it to...
 Rose::HTML::Form::Field::DateTime->import_methods
@@ -15,6 +15,11 @@ Rose::HTML::Form::Field::DateTime->import_methods
   'validate',
 );
 
+Rose::HTML::Form::Field::Compound->import_methods
+(
+  'name',
+);
+
 # sub internal_value
 # {
 #   my $value = shift->SUPER::internal_value(@_);
